@@ -1,9 +1,10 @@
+import argparse
+import asyncio
+import logging
 import os
 import sys
-import asyncio
-import argparse
-import logging
-from mendiafilescraper.Scrapper import Scrapper
+
+from mendiafilescraper.Scraper import Scraper
 
 
 async def run(arguments):
@@ -14,28 +15,26 @@ async def run(arguments):
         return 1
 
     if arguments.debug:
-        logger = logging.getLogger(Scrapper.__name__)
+        logger = logging.getLogger(Scraper.__name__)
         logger.setLevel(level="DEBUG")
         logging.debug(f"Running {__name__} with --debug")
 
     path = os.getcwd()
     env_path = os.environ["PATH"]
-    if not env_path.endswith(';'):
-        env_path += ';'
+    if not env_path.endswith(";"):
+        env_path += ";"
     env_path += path
     os.environ["PATH"] = env_path
 
-    scrapper = Scrapper(
-        debug=arguments.debug
-    )
-
-    if arguments.scan:
-        await scrapper.scan(
-            publish=arguments.publish,
-        )
+    scraper = Scraper(debug=arguments.debug)
 
     if arguments.setup:
-        scrapper.setup()
+        return await scraper.setup()
+
+    if arguments.scan:
+        return await scraper.scan(
+            publish=arguments.publish,
+        )
 
 
 def main():
